import math

class Segment:
    """Class for a segment in the diagram

    Contains the data for one segment and
    the methods to generate the SVG for
    the segment"""
    
    def __init__( self, lst ):
        """Constructs a segment from a list of strings"""
        self.offset = 0.0
        self.size   = lst[0]
        self.name   = lst[-1]
        self.parent = "/".join( lst[1:-1] )
        self.angle  = 0
        self.cx     = 0
        self.cy     = 0
        self.color  = None

    def set_color( self, color ):
        self.color = color

    def write_path( self, parents, center, radius, ringwidth ):
        """Writes the path element for the segment to STDOUT"""
        if self.color == None:
            self.color = parents[self.parent].color

        start = parents[self.parent].offset
        end   = start + self.angle
        parents[self.parent].offset = end
        self.offset = start
        parents[f"{self.parent}/{self.name}"] = self

        flag = 1 if (end - start) > math.pi else 0

        # Shorten the names for better readability of the path string
        rw = ringwidth
        r  = radius
    
        p1 = self.point( center, r + rw, start )
        p2 = self.point( center, r + rw, end   )
        p3 = self.point( center, r,      end   )
        p4 = self.point( center, r,      start )

        self.cx = center + (r+rw/2) * math.sin(start+self.angle/2)
        self.cy = center - (r+rw/2) * math.cos(start+self.angle/2)

        print( f" <path d=\"M {p1} A {r+rw} {r+rw} 0 {flag} 1 {p2} L {p3} A {r} {r} 0 {flag} 0 {p4} Z\" fill=\"{self.color}\" stroke=\"white\">" )
        print( f" <title>{self.name}</title>" )
        print( " </path>" )

    def write_text( self ):
        if self.angle > 0.35:
            print( f"<text x=\"{self.cx}\" y=\"{self.cy}\">{self.name}</text>" )

    def point( self, center, radius, angle ):
        return f"{center+radius*math.sin(angle)} {center-radius*math.cos(angle)}"

