from segment import Segment
import math
import sys

RINGWIDTH = 60

def read_data():
    """Read the output of du"""

    # One list for each path length
    data = [ [], [], [], [], [] ]

    for line in sys.stdin:
        if line.count("/") < len(data):
            line = line.strip()
            line = line.replace("\t","/")
            lst = line.split("/")

            data[len(lst)-2].append( Segment(lst) )

    return data

def init( data ):
    """Initialize factor and parents"""
    root = data[0][0]
    return { root.name : root }, (2 * math.pi) / float(root.size)


def prepare_lists( data, factor, limit ):
    """Sorts the ring segments, computes the angles and eliminates tiny segments"""
    for lst in data[1:]:
        lst.sort( key = lambda s: int(s.size), reverse = True )

        for i in range( len(lst)-1, -1, -1 ):
            angle = float(lst[i].size) * factor
            if  angle >= limit:
                lst[i].angle = angle
            else:
                del lst[i]

def assign_colors( data ):
    """Assigns the colors to the segments in the first ring"""
    ring   = data[1]
    length = len(ring)
    for i in range(length):
        ring[i].set_color( f"hsl({int(360.0/length*(length-i))},70%,50%)" )

def main():
    data            = read_data()
    parents, factor = init( data )

    prepare_lists( data, factor, 0.017453293 )
    assign_colors( data )

    print( "<?xml version=\"1.0\" encoding=\"UTF-8\"?>" )
    print( "<svg xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 560 560\">" )

    radius = 25
    for ring in data[1:]:
        for segment in ring:
            segment.write_path( parents, 280, radius, RINGWIDTH )
        radius = radius + RINGWIDTH

    print( " <g pointer-events=\"none\" text-anchor=\"middle\" font-size=\"10\" font-family=\"sans-serif\" font-weight=\"bold\">" )

    for ring in data[1:]:
        for segment in ring:
            segment.write_text()

    print( " </g>" )
    print( "</svg>" )

if( __name__ == "__main__" ):
    main()
